@@ -52,6 +52,13 @@ typedef struct Track ChordTrack;
 ChordTrack *
 chord_track_new ();
 
+/**
+ * Inits a chord track (e.g. when cloning).
+ */
+void
+chord_track_init (
+  Track * track);
+
 /**
  * Adds a ChordObject to the Track.
  *
