@@ -308,12 +308,15 @@ project_load (
  *
  * @param is_backup 1 if this is a backup. Backups
  *   will be saved as <original filename>.bak<num>.
+ * @param show_notification Show a notification
+ *   in the UI that the project was saved.
  */
 int
 project_save (
   Project *    self,
-  const char * dir,
-  int          is_backup);
+  const char * _dir,
+  const int    is_backup,
+  const int    show_notification);
 
 /**
  * Autosave callback.
