@@ -101,8 +101,9 @@ typedef struct Position Position;
  * of the window is needed on the caller side.
  */
 #define ui_show_error_message(win, msg) \
-    ui_show_error_message_full ( \
+    ui_show_message_full ( \
       GTK_WINDOW (win), \
+      GTK_MESSAGE_ERROR, \
       msg);
 
 #define ui_is_widget_revealed(widget) \
@@ -146,7 +147,9 @@ typedef enum UiOverlayAction
   UI_OVERLAY_ACTION_CREATING_RESIZING_R,
   UI_OVERLAY_ACTION_CREATING_MOVING,
   UI_OVERLAY_ACTION_RESIZING_L,
+  UI_OVERLAY_ACTION_RESIZING_L_LOOP,
   UI_OVERLAY_ACTION_RESIZING_R,
+  UI_OVERLAY_ACTION_RESIZING_R_LOOP,
   UI_OVERLAY_ACTION_RESIZING_UP,
   UI_OVERLAY_ACTION_STRETCHING_L,
   UI_OVERLAY_ACTION_STRETCHING_R,
@@ -193,7 +196,7 @@ typedef enum UiOverlayAction
   ui_set_cursor_from_icon_name ( \
     GTK_WIDGET (widget), \
     "z-edit-select", \
-    3, 6);
+    5, 4);
 
 #define ui_set_pencil_cursor(widget) \
   ui_set_cursor_from_icon_name ( \
@@ -228,8 +231,32 @@ typedef enum UiOverlayAction
 #define ui_set_hand_cursor(widget) \
   ui_set_cursor_from_icon_name ( \
     GTK_WIDGET (widget), \
-    "z-hand", \
-    3, 6);
+    "z-labplot-transform-move", \
+    10, 10);
+
+#define ui_set_left_resize_cursor(widget) \
+  ui_set_cursor_from_icon_name ( \
+    GTK_WIDGET (widget), \
+    "left-resize", \
+    0, 10);
+
+#define ui_set_left_resize_loop_cursor(widget) \
+  ui_set_cursor_from_icon_name ( \
+    GTK_WIDGET (widget), \
+    "left-resize-loop", \
+    0, 10);
+
+#define ui_set_right_resize_cursor(widget) \
+  ui_set_cursor_from_icon_name ( \
+    GTK_WIDGET (widget), \
+    "right-resize", \
+    15, 10);
+
+#define ui_set_right_resize_loop_cursor(widget) \
+  ui_set_cursor_from_icon_name ( \
+    GTK_WIDGET (widget), \
+    "right-resize-loop", \
+    15, 10);
 
 /**
  * Sets cursor from icon name.
@@ -253,9 +280,14 @@ ui_on_motion_set_status_bar_text_cb (
   GdkEvent *  event,
   char *      text);
 
+/**
+ * Shows a popup message of the given type with the
+ * given message.
+ */
 void
-ui_show_error_message_full (
+ui_show_message_full (
   GtkWindow * parent_window,
+  GtkMessageType type,
   const char * message);
 
 /**
