@@ -27,6 +27,7 @@
 
 #include "actions/actions.h"
 #include "actions/undo_manager.h"
+#include "actions/create_timeline_selections_action.h"
 #include "actions/create_tracks_action.h"
 #include "actions/delete_tracks_action.h"
 #include "actions/delete_midi_arranger_selections_action.h"
@@ -537,7 +538,7 @@ activate_save (GSimpleAction *action,
      }
    g_message ("%s project dir", PROJECT->dir);
 
-   project_save (PROJECT, PROJECT->dir, 0);
+   project_save (PROJECT, PROJECT->dir, 0, 1);
 }
 
 void
@@ -587,7 +588,7 @@ activate_save_as (GSimpleAction *action,
 
       filename =
         gtk_file_chooser_get_filename (chooser);
-      project_save (PROJECT, filename, 0);
+      project_save (PROJECT, filename, 0, 1);
       g_free (filename);
     }
 
@@ -696,6 +697,16 @@ on_timeline_clipboard_received (
     {
       timeline_selections_paste_to_pos (
         ts, PLAYHEAD);
+
+      /* create action to make it undoable */
+      /* (by now the TL_SELECTIONS should have
+       * only the pasted items selected) */
+      UndoableAction * ua =
+        (UndoableAction *)
+        create_timeline_selections_action_new (
+          TL_SELECTIONS);
+      undo_manager_perform (
+        UNDO_MANAGER, ua);
     }
 
   /* free ts */
@@ -990,6 +1001,23 @@ activate_create_audio_bus_track (GSimpleAction *action,
   undo_manager_perform (UNDO_MANAGER, ua);
 }
 
+void
+activate_create_midi_bus_track (
+  GSimpleAction *action,
+  GVariant      *variant,
+  gpointer       user_data)
+{
+  UndoableAction * ua =
+    create_tracks_action_new (
+      TRACK_TYPE_MIDI_BUS,
+      NULL,
+      NULL,
+      TRACKLIST->num_tracks,
+      1);
+
+  undo_manager_perform (UNDO_MANAGER, ua);
+}
+
 void
 activate_create_audio_group_track (
   GSimpleAction *action,
@@ -1007,6 +1035,22 @@ activate_create_audio_group_track (
   undo_manager_perform (UNDO_MANAGER, ua);
 }
 
+void
+activate_create_midi_group_track (
+  GSimpleAction *action,
+  GVariant      *variant,
+  gpointer       user_data)
+{
+  UndoableAction * ua =
+    create_tracks_action_new (
+      TRACK_TYPE_MIDI_GROUP,
+      NULL,
+      NULL,
+      TRACKLIST->num_tracks,
+      1);
+
+  undo_manager_perform (UNDO_MANAGER, ua);
+}
 
 void
 activate_duplicate_selected_tracks (
