@@ -1289,71 +1289,79 @@ channel_reconnect_ext_input_ports (
   if (ch->track->type == TRACK_TYPE_INSTRUMENT ||
       ch->track->type == TRACK_TYPE_MIDI)
     {
-      /* disconnect */
-      const char ** prev_ports =
-        jack_port_get_all_connections (
-          AUDIO_ENGINE->client,
-          (jack_port_t *)
-            ch->midi_in->data);
-      if (prev_ports)
+      if (AUDIO_ENGINE->audio_backend ==
+            AUDIO_BACKEND_JACK &&
+          AUDIO_ENGINE->midi_backend ==
+            MIDI_BACKEND_JACK)
         {
-          i = 0;
-          while ((pname = (char *) prev_ports[i]) !=
-                    NULL)
-            {
-              ret =
-                jack_disconnect (
-                  AUDIO_ENGINE->client,
-                  pname,
-                  jack_port_name (
-                    (jack_port_t *)
-                    ch->midi_in->data));
-              g_warn_if_fail (!ret);
-              i++;
-            }
-        }
-
-      /* connect to all external midi ins */
-      if (ch->all_midi_ins)
-        {
-          const char ** ports =
-            jack_get_ports (
+#ifdef HAVE_JACK
+          /* disconnect */
+          const char ** prev_ports =
+            jack_port_get_all_connections (
               AUDIO_ENGINE->client,
-              NULL, JACK_DEFAULT_MIDI_TYPE,
-              JackPortIsOutput |
-              JackPortIsPhysical);
+              (jack_port_t *)
+                ch->midi_in->data);
+          if (prev_ports)
+            {
+              i = 0;
+              while ((pname = (char *) prev_ports[i]) !=
+                        NULL)
+                {
+                  ret =
+                    jack_disconnect (
+                      AUDIO_ENGINE->client,
+                      pname,
+                      jack_port_name (
+                        (jack_port_t *)
+                        ch->midi_in->data));
+                  g_warn_if_fail (!ret);
+                  i++;
+                }
+            }
 
-          i = 0;
-          jack_port_t * jport;
-          while ((pname = (char *) ports[i]) !=
-                    NULL)
+          /* connect to all external midi ins */
+          if (ch->all_midi_ins)
             {
-              ret =
-                jack_connect (
+              const char ** ports =
+                jack_get_ports (
                   AUDIO_ENGINE->client,
-                  pname,
-                  jack_port_name (
-                    (jack_port_t *)
-                    ch->midi_in->data));
-              g_warn_if_fail (!ret);
-              i++;
+                  NULL, JACK_DEFAULT_MIDI_TYPE,
+                  JackPortIsOutput |
+                  JackPortIsPhysical);
+
+              i = 0;
+              jack_port_t * jport;
+              while ((pname = (char *) ports[i]) !=
+                        NULL)
+                {
+                  ret =
+                    jack_connect (
+                      AUDIO_ENGINE->client,
+                      pname,
+                      jack_port_name (
+                        (jack_port_t *)
+                        ch->midi_in->data));
+                  g_warn_if_fail (!ret);
+                  i++;
+                }
             }
-        }
-      /* connect to selected midi ins */
-      else
-        {
-          for (i = 0; i < ch->num_ext_midi_ins;
-               i++)
+          /* connect to selected midi ins */
+          else
             {
-              ret =
-                jack_connect (
-                  AUDIO_ENGINE->client,
-                  ch->ext_midi_ins[i]->full_name,
-                  jack_port_name (
-                    (jack_port_t *)
-                    ch->midi_in->data));
-              g_warn_if_fail (!ret);
+              for (i = 0; i < ch->num_ext_midi_ins;
+                   i++)
+                {
+                  ret =
+                    jack_connect (
+                      AUDIO_ENGINE->client,
+                      ch->ext_midi_ins[i]->full_name,
+                      jack_port_name (
+                        (jack_port_t *)
+                        ch->midi_in->data));
+                  g_warn_if_fail (!ret);
+                }
             }
+#endif
         }
     }
 }
@@ -1484,7 +1492,7 @@ channel_connect (
         MONITOR_FADER->stereo_in->r,
         1);
     }
-  else
+  else if (ch->track->out_signal_type == TYPE_AUDIO)
     {
       ch->output = P_MASTER_TRACK;
       ch->output_pos = P_MASTER_TRACK->pos;
@@ -1555,23 +1563,51 @@ channel_update_output (
   Channel * ch,
   Track * output)
 {
-  /* disconnect Channel's output from the current
-   * output channel */
-  port_disconnect (
-    ch->stereo_out->l,
-    ch->output->channel->stereo_in->l);
-  port_disconnect (
-    ch->stereo_out->r,
-    ch->output->channel->stereo_in->r);
+  if (ch->output)
+    {
+      /* disconnect Channel's output from the
+       * current
+       * output channel */
+      switch (ch->output->in_signal_type)
+        {
+        case TYPE_AUDIO:
+          port_disconnect (
+            ch->stereo_out->l,
+            ch->output->channel->stereo_in->l);
+          port_disconnect (
+            ch->stereo_out->r,
+            ch->output->channel->stereo_in->r);
+          break;
+        case TYPE_EVENT:
+          port_disconnect (
+            ch->midi_out,
+            ch->output->channel->midi_in);
+          break;
+        default:
+          break;
+        }
+    }
 
   /* connect Channel's output to the given output
    */
-  port_connect (
-    ch->stereo_out->l,
-    output->channel->stereo_in->l, 1);
-  port_connect (
-    ch->stereo_out->r,
-    output->channel->stereo_in->r, 1);
+  switch (output->in_signal_type)
+    {
+    case TYPE_AUDIO:
+      port_connect (
+        ch->stereo_out->l,
+        output->channel->stereo_in->l, 1);
+      port_connect (
+        ch->stereo_out->r,
+        output->channel->stereo_in->r, 1);
+      break;
+    case TYPE_EVENT:
+      port_connect (
+        ch->midi_out,
+        output->channel->midi_in, 1);
+      break;
+    default:
+      break;
+    }
 
   ch->output = output;
   g_message ("setting output %s",
