@@ -46,14 +46,8 @@ on_open_directory_clicked (
   ExportProgressDialogWidget * self)
 {
   char * dir = io_get_dir (self->info->file_uri);
-  char * command =
-    g_strdup_printf (
-      "xdg-open \"%s\"",
-      dir);
-  FILE* file = popen (command, "r");
-  pclose(file);
+  io_open_directory (dir);
   g_free (dir);
-  g_free (command);
 }
 
 static void
