@@ -263,12 +263,16 @@ main_window_widget_init (MainWindowWidget * self)
       activate_create_audio_track },
     { "create-ins-track",
       activate_create_ins_track },
-    { "create-bus-track",
+    { "create-audio-bus-track",
       activate_create_audio_bus_track },
+    { "create-midi-bus-track",
+      activate_create_midi_bus_track },
     { "create-midi-track",
       activate_create_midi_track },
-    { "create-group-track",
+    { "create-audio-group-track",
       activate_create_audio_group_track },
+    { "create-midi-group-track",
+      activate_create_midi_group_track },
     { "delete-selected-tracks",
       activate_delete_selected_tracks },
 
