@@ -333,6 +333,9 @@ on_motion (GtkWidget *      widget,
       rw_prv->resize_r =
         region_widget_is_resize_r (
           self, event->x);
+      rw_prv->resize_loop =
+        region_widget_is_resize_loop (
+          self, event->y);
       rw_prv->hover_x = event->x;
     }
 
@@ -473,6 +476,36 @@ region_widget_is_resize_r (
   return 0;
 }
 
+/**
+ * Returns if the current position is for resizing
+ * loop.
+ */
+int
+region_widget_is_resize_loop (
+  RegionWidget * self,
+  int             y)
+{
+  REGION_WIDGET_GET_PRIVATE (self);
+
+  Region * r = rw_prv->region;
+  if ((position_to_ticks (&r->end_pos) -
+       position_to_ticks (&r->start_pos)) >
+      position_to_ticks (&r->loop_end_pos))
+    {
+      return 1;
+    }
+
+  int height =
+    gtk_widget_get_allocated_height (
+      GTK_WIDGET (self));
+
+  if (y > height / 2)
+    {
+      return 1;
+    }
+  return 0;
+}
+
 RegionWidgetPrivate *
 region_widget_get_private (RegionWidget * self)
 {
