@@ -287,8 +287,13 @@ timeline_arranger_widget_get_cursor (
       self,
       ar_prv->hover_x,
       ar_prv->hover_y);
+  MarkerWidget * mw =
+    timeline_arranger_widget_get_hit_marker (
+      self,
+      ar_prv->hover_x,
+      ar_prv->hover_y);
 
-  int is_hit = rw || sw;
+  int is_hit = rw || sw || mw;
 
   switch (action)
     {
@@ -310,9 +315,19 @@ timeline_arranger_widget_get_cursor (
                     rw && rw_prv->resize_l;
                   int is_resize_r =
                     rw && rw_prv->resize_r;
-                  if (is_resize_l)
+                  int is_resize_loop =
+                    rw && rw_prv->resize_loop;
+                  if (is_resize_l &&
+                      is_resize_loop)
+                    return
+                      ARRANGER_CURSOR_RESIZING_L_LOOP;
+                  else if (is_resize_l)
                     return
                       ARRANGER_CURSOR_RESIZING_L;
+                  else if (is_resize_r &&
+                           is_resize_loop)
+                    return
+                      ARRANGER_CURSOR_RESIZING_R_LOOP;
                   else if (is_resize_r)
                     return
                       ARRANGER_CURSOR_RESIZING_R;
@@ -390,12 +405,24 @@ timeline_arranger_widget_get_cursor (
       else
         ac = ARRANGER_CURSOR_RESIZING_L;
       break;
+    case UI_OVERLAY_ACTION_RESIZING_L_LOOP:
+      if (self->resizing_range)
+        ac = ARRANGER_CURSOR_RANGE;
+      else
+        ac = ARRANGER_CURSOR_RESIZING_L_LOOP;
+      break;
     case UI_OVERLAY_ACTION_RESIZING_R:
       if (self->resizing_range)
         ac = ARRANGER_CURSOR_RANGE;
       else
         ac = ARRANGER_CURSOR_RESIZING_R;
       break;
+    case UI_OVERLAY_ACTION_RESIZING_R_LOOP:
+      if (self->resizing_range)
+        ac = ARRANGER_CURSOR_RANGE;
+      else
+        ac = ARRANGER_CURSOR_RESIZING_R_LOOP;
+      break;
     default:
       ac = ARRANGER_CURSOR_SELECT;
       break;
@@ -762,6 +789,7 @@ void
 timeline_arranger_widget_on_drag_begin_region_hit (
   TimelineArrangerWidget * self,
   double                   start_x,
+  double                   start_y,
   RegionWidget *           rw)
 {
   ARRANGER_WIDGET_GET_PRIVATE (self);
@@ -792,10 +820,20 @@ timeline_arranger_widget_on_drag_begin_region_hit (
   gtk_widget_translate_coordinates (
     GTK_WIDGET (self),
     GTK_WIDGET (rw),
-    start_x, 0, &wx, &wy);
+    start_x, start_y, &wx, &wy);
 
   self->start_region = region;
 
+  int resize_l =
+    region_widget_is_resize_l (rw, wx);
+  int resize_r =
+    region_widget_is_resize_r (rw, wx);
+  int resize_loop =
+    region_widget_is_resize_loop (rw, wy);
+  int show_cut_lines =
+    region_widget_should_show_cut_lines (
+      ar_prv->alt_held);
+
 #define SET_ACTION(x) \
   ar_prv->action = UI_OVERLAY_ACTION_##x
 
@@ -809,18 +847,21 @@ timeline_arranger_widget_on_drag_begin_region_hit (
       SET_ACTION (AUDITIONING);
       break;
     case TOOL_SELECT_NORMAL:
-      if (region_widget_is_resize_l (rw, wx))
+      if (resize_l && resize_loop)
+        SET_ACTION (RESIZING_L_LOOP);
+      else if (resize_l)
         SET_ACTION (RESIZING_L);
-      else if (region_widget_is_resize_r (rw, wx))
+      else if (resize_r && resize_loop)
+        SET_ACTION (RESIZING_R_LOOP);
+      else if (resize_r)
         SET_ACTION (RESIZING_R);
-      else if (region_widget_should_show_cut_lines (
-                 ar_prv->alt_held))
+      else if (show_cut_lines)
         SET_ACTION (CUTTING);
       else
         SET_ACTION (STARTING_MOVING);
       break;
     case TOOL_SELECT_STRETCH:
-      if (region_widget_is_resize_l (rw, wx))
+      if (resize_l)
         SET_ACTION (STRETCHING_L);
       else if (region_widget_is_resize_r (rw, wx))
         SET_ACTION (STRETCHING_R);
@@ -883,6 +924,7 @@ void
 timeline_arranger_widget_on_drag_begin_scale_hit (
   TimelineArrangerWidget * self,
   double                   start_x,
+  double                   start_y,
   ScaleObjectWidget *      cw)
 {
   ARRANGER_WIDGET_GET_PRIVATE (self);
@@ -935,6 +977,7 @@ void
 timeline_arranger_widget_on_drag_begin_marker_hit (
   TimelineArrangerWidget * self,
   double                   start_x,
+  double                   start_y,
   MarkerWidget *           mw)
 {
   ARRANGER_WIDGET_GET_PRIVATE (self);
@@ -1392,9 +1435,20 @@ snap_region_l (
     {
       if (region_validate_start_pos (
             region, new_start_pos))
-        region_set_start_pos (
-          region, new_start_pos,
-          AO_UPDATE_ALL);
+        {
+          /*region_set_start_pos (*/
+            /*region, new_start_pos,*/
+            /*AO_UPDATE_ALL);*/
+          long diff =
+            position_to_ticks (new_start_pos) -
+            position_to_ticks (
+              &region->start_pos);
+          region_resize (
+            region, 1, diff,
+            ar_prv->action ==
+              UI_OVERLAY_ACTION_RESIZING_L_LOOP,
+            AO_UPDATE_ALL);
+        }
     }
 
   return 0;
@@ -1440,7 +1494,7 @@ timeline_arranger_widget_snap_regions_l (
     {
       /* main trans region */
       region =
-        region_get_main_trans_region (
+        region_get_main_region (
           TL_SELECTIONS->regions[i]);
 
       /* caclulate new start position */
@@ -1456,17 +1510,6 @@ timeline_arranger_widget_snap_regions_l (
 
       if (ret)
         return ret;
-
-      /* lane trans region */
-      region =
-        ((Region *) region->obj_info.lane_trans);
-
-      ret =
-        snap_region_l (
-          self, region, &new_start_pos, dry_run);
-
-      if (ret)
-        return ret;
     }
 
   EVENTS_PUSH (ET_REGION_POSITIONS_CHANGED, NULL);
@@ -1526,8 +1569,16 @@ snap_region_r (
       if (region_validate_end_pos (
             region, new_end_pos))
         {
-          region_set_end_pos (
-            region, new_end_pos, AO_UPDATE_ALL);
+          /*region_set_end_pos (*/
+            /*region, new_end_pos, AO_UPDATE_ALL);*/
+          long diff =
+            position_to_ticks (new_end_pos) -
+            position_to_ticks (&region->end_pos);
+          region_resize (
+            region, 0, diff,
+            ar_prv->action ==
+              UI_OVERLAY_ACTION_RESIZING_R_LOOP,
+            AO_UPDATE_ALL);
 
           /* if creating also set the loop points
            * appropriately */
@@ -1546,9 +1597,6 @@ snap_region_r (
                 region, &tmp, AO_UPDATE_ALL);
 
               /* use the setters */
-              region_set_true_end_pos (
-                region, &region->true_end_pos,
-                AO_UPDATE_ALL);
               region_set_loop_end_pos (
                 region, &region->true_end_pos,
                 AO_UPDATE_ALL);
@@ -1938,6 +1986,29 @@ timeline_arranger_widget_on_drag_end (
             TL_SELECTIONS, 1);
         }
       break;
+    case UI_OVERLAY_ACTION_RESIZING_L_LOOP:
+      if (!self->resizing_range)
+        {
+          Region * main_trans_region =
+            TL_SELECTIONS->regions[0]->obj_info.
+              main_trans;
+          UndoableAction * ua =
+            (UndoableAction *)
+            edit_timeline_selections_action_new (
+              TL_SELECTIONS,
+              ETS_RESIZE_L_LOOP,
+              position_to_ticks (
+                &main_trans_region->start_pos) -
+              position_to_ticks (
+                &main_trans_region->
+                  cache_start_pos),
+              NULL, NULL);
+          undo_manager_perform (
+            UNDO_MANAGER, ua);
+          timeline_selections_reset_counterparts (
+            TL_SELECTIONS, 1);
+        }
+      break;
     case UI_OVERLAY_ACTION_RESIZING_R:
       if (!self->resizing_range)
         {
@@ -1960,6 +2031,28 @@ timeline_arranger_widget_on_drag_end (
             TL_SELECTIONS, 1);
         }
       break;
+    case UI_OVERLAY_ACTION_RESIZING_R_LOOP:
+      if (!self->resizing_range)
+        {
+          Region * main_trans_region =
+            TL_SELECTIONS->regions[0]->obj_info.
+              main_trans;
+          UndoableAction * ua =
+            (UndoableAction *)
+            edit_timeline_selections_action_new (
+              TL_SELECTIONS,
+              ETS_RESIZE_R_LOOP,
+              position_to_ticks (
+                &main_trans_region->end_pos) -
+              position_to_ticks (
+                &main_trans_region->cache_end_pos),
+              NULL, NULL);
+          undo_manager_perform (
+            UNDO_MANAGER, ua);
+          timeline_selections_reset_counterparts (
+            TL_SELECTIONS, 1);
+        }
+      break;
     case UI_OVERLAY_ACTION_STARTING_MOVING:
       /* if something was clicked with ctrl without
        * moving*/
