@@ -438,12 +438,30 @@ load (
 
   Project * prj = project_deserialize (yaml);
 
+  char * version = zrythm_get_version (0);
+  if (!string_is_equal (
+        prj->version,
+        version, 1))
+    {
+      char * str =
+        g_strdup_printf (
+          _("This project was created with a "
+            "different version of Zrythm (%s). "
+            "It may not work correctly."),
+          prj->version);
+      ui_show_message_full (
+        GTK_WINDOW (MAIN_WINDOW),
+        GTK_MESSAGE_WARNING, str);
+      g_free (str);
+    }
+  g_free (version);
+
   if (prj == NULL)
     {
       ui_show_error_message (
         MAIN_WINDOW,
-        "Failed to load project. Please check the "
-        "logs for more information.");
+        _("Failed to load project. Please check the "
+        "logs for more information."));
       RETURN_ERROR;
     }
   g_message ("Project successfully deserialized.");
@@ -603,6 +621,9 @@ project_load (
   PROJECT->version =
     zrythm_get_version (0);
 
+  if (is_template || !filename)
+    project_save (PROJECT, PROJECT->dir, 0, 0);
+
   return 0;
 }
 
@@ -618,7 +639,7 @@ project_autosave_cb (
       PROJECT->datetime_str)
     {
       project_save (
-        PROJECT, PROJECT->dir, 1);
+        PROJECT, PROJECT->dir, 1, 1);
     }
 
   return G_SOURCE_CONTINUE;
@@ -652,6 +673,8 @@ project_get_backups_dir (
 
 /**
  * Returns the exports dir for the given Project.
+ *
+ * Must be g_free()'d.
  */
 char *
 project_get_exports_dir (
@@ -739,12 +762,15 @@ project_get_project_file_path (
  *
  * @param is_backup 1 if this is a backup. Backups
  *   will be saved as <original filename>.bak<num>.
+ * @param show_notification Show a notification
+ *   in the UI that the project was saved.
  */
 int
 project_save (
   Project *    self,
   const char * _dir,
-  int          is_backup)
+  const int    is_backup,
+  const int    show_notification)
 {
   int i, j;
 
@@ -754,6 +780,10 @@ project_save (
    * exist */
   set_dir (self, dir);
   io_mkdir (PROJECT->dir);
+  char * exports_dir =
+    project_get_exports_dir (PROJECT);
+  io_mkdir (exports_dir);
+  g_free (exports_dir);
 
   /* set the title */
   char * basename =
@@ -841,13 +871,15 @@ project_save (
 
   if (is_backup)
     {
-      ui_show_notification (_("Backup saved."));
+      if (show_notification)
+        ui_show_notification (_("Backup saved."));
     }
   else
     {
       zrythm_add_to_recent_projects (
         ZRYTHM, project_file_path);
-      ui_show_notification (_("Project saved."));
+      if (show_notification)
+        ui_show_notification (_("Project saved."));
     }
   g_free (project_file_path);
 
